% Super Spectrogram Example
% ------------------------------------------------
%
% Juhan Nam
% Apr-11-2010: initial version
% Mar-11-2013: ogranized old files 


%%%%% default parameters %%%%%

% STFT
stft_options.sr = 8000;
stft_options.M1 = 64;
stft_options.M2 = 512;
stft_options.hop = 16;
stft_options.win = 'hann';
stft_options.N = 1024;

% PLCA
plca_options.max_iter = 10;
plca_options.dic_size = 3;

%%%%% choose an example %%%%%

example = 'sine_plus_impulse';
%example = 'linear_chirp';
%example = 'speech1';
%example = 'glocken';
%example = 'piano';


if strcmp(example, 'sine_plus_impulse')
    % sin plus impulse: synthetic example
    f0 = 1000;
    x_impulse = [zeros(5000,1); 1; zeros(5000,1)];
    x_sin = sin(2*pi*f0*[0:length(x_impulse)-1]'/stft_options.sr);
    x = 0.01*x_sin+x_impulse;
    plca_options.max_iter = 20;
    plca_options.dic_size = 2;
    plca_options.seg_size = length(x);

elseif strcmp(example, 'linear_chirp')
    % linear chirp: synthetic example
    sr = 8000;          % sampling frequency (arbitrary)
    D = 1;               % duration in seconds
    L = ceil(sr*D)+1;   % signal duration (samples)
    n = 0:L-1;          % discrete-time axis (samples)
    t = n/sr;           % discrete-time axis (sec)
    x = chirp(t,100,D,4000,'logarithmic');

    stft_options.M1 = 128;
    stft_options.M2 = 1024;
    stft_options.hop = 32;
    stft_options.N = 1024;
    plca_options.max_iter = 50;
    plca_options.dic_size = 100;
    plca_options.seg_size = stft_options.sr;

elseif strcmp(example, 'speech1')
    % speech
    [x,sr] = wavread('jobs.wav');
    x = x(1:sr*1.5);
    
    stft_options.sr = sr;
    stft_options.M1 = 64;
    stft_options.M2 = 256;
    stft_options.hop = 8;
    stft_options.N = 1024;
    plca_options.max_iter = 80;
    plca_options.dic_size = 50;
    plca_options.seg_size = stft_options.sr;

elseif strcmp(example, 'glocken')
    % Glockenspiel
    [x,sr] = wavread('glockenspiel.wav');
    x = resample(x(:,1),1,2); sr = sr/2;
    x = x(1:2*sr)+eps;
    
    stft_options.sr = sr;
    stft_options.M1 = 128;
    stft_options.M2 = 1024;
    stft_options.hop = 32;
    stft_options.N = 2048;
    plca_options.max_iter = 50;
    plca_options.dic_size = 30;
    plca_options.seg_size = stft_options.sr;
elseif strcmp(example, 'piano')
    % Glockenspiel
    [x,sr] = wavread('piano.wav');
    x = resample(x(:,1), 8000, sr); sr = 8000;
    x = x(1*sr:5*sr)+eps;
    
    stft_options.sr = sr;
    stft_options.M1 = 128;
    stft_options.M2 = 1024;
    stft_options.hop = 32;
    stft_options.N = 1024;
    plca_options.max_iter = 30;
    plca_options.dic_size = 30;
    plca_options.seg_size = stft_options.sr;
end
    
[super_spec, spec_t, spec_f, w, zf, zt, h]  = super_spectrogram(x, stft_options, plca_options);

figure(1);
t = (0:size(spec_t,2)-1)*stft_options.hop/stft_options.sr;
f = stft_options.sr*[0:size(spec_t,1)-1]/stft_options.N/1000;

subplot(2,2,1)
max_val = max(max(db(abs(spec_t))));
imagesc(t, f, db(abs(spec_t)),[max_val-60 max_val]); axis xy; %colorbar;
title('High time-resolution spectrogram','fontsize',12);
xlabel('Time [sec.]','fontsize',12); ylabel('Frequency [kHz]','fontsize',12);
set(gca,'fontsize',12,'fontname','times');

subplot(2,2,2)
max_val = max(max(db(abs(spec_f))));
imagesc(t, f, db(abs(spec_f)),[max_val-60 max_val]); axis xy; %colorbar;
title('High frequency-resolution spectrogram','fontsize',12);
xlabel('Time [sec.]','fontsize',12); ylabel('Frequency [kHz]','fontsize',12);
set(gca,'fontsize',12,'fontname','times');

subplot(2,2,3)
temp = sqrt(spec_t.*spec_f);
max_val = max(max(db(abs(temp))));
imagesc(t, f, db(abs(temp)),[max_val-60 max_val]); axis xy; %colorbar;
title('Element-wise multiplication spectrogram','fontsize',12);
xlabel('Time [sec.]','fontsize',12); ylabel('Frequency [kHz]','fontsize',12);
set(gca,'fontsize',12,'fontname','times');

subplot(2,2,4)
max_val = max(max(db(abs(super_spec))));
imagesc(t, f, db(abs(super_spec)),[max_val-60 max_val]); axis xy; %colorbar;
title('Super-resolution spectrogram','fontsize',12);
xlabel('Time [sec.]','fontsize',12); ylabel('Frequency [kHz]','fontsize',12);
set(gca,'fontsize',12,'fontname','times');
%

 



