function [super_spec, spec_t, spec_f, w, zf, zt, h] = super_spectrogram(x, stft_options, plca_options)
% y = super_spectrogram(x, stft_options, plca_options)
%   Super-resolution spectrogram
%   x: input waveform
%   stft_options
%       N: FFT size (default: 256)
%       win: type of window. The name follows the list of windows shown in "help window" 
%       M1: wide-band window size 
%       M2: narrow-band window size ( M1 < M2 )
%       hop: hop size
%       sr: sampling rate (default: 8000Hz)
%   plca_options
%       max_iter: max iteration of learning
%       dic_size: dictionary size
%
% Juhan Nam
% Mar-7-2013: reorganized from old code

%% blurring function

short_win =eval(['window(@' stft_options.win ', ' num2str(stft_options.M1) ')']);
long_win =eval(['window(@' stft_options.win ', ' num2str(stft_options.M2) ')']);
 
[b_time, b_freq] = blurring_function(stft_options.M1, stft_options.M2, stft_options.hop, stft_options.N, short_win, long_win);

%% two spectrograms

% high time and low frequency resolution
align_sz = floor((stft_options.M2-stft_options.M1)/2);

x_t = x(align_sz+1:end); % for alignment betwen two spectrograms
spec_t = stft(x_t, stft_options.N, short_win, stft_options.hop, stft_options.sr);
spec_f = stft(x, stft_options.N, long_win, stft_options.hop, stft_options.sr); 

% adjust the number of frames such that they are equal for both 
nFrames = min(size(spec_t,2), size(spec_f,2));
spec_t = spec_t(:,1:nFrames);
spec_f = spec_f(:,1:nFrames);


%% Super spectrogram using two spectrograms and coupled PLCA

seg_size = floor(plca_options.seg_size/stft_options.hop);
num_segs = ceil(nFrames/seg_size);

super_spec_buffer = cell(num_segs,1);

count = 0;
for n=1:seg_size:nFrames
    count = count + 1;
    index = [n:min(n+seg_size,nFrames)];
    spec_t_seg = abs(spec_t(:,index));
    spec_t_seg_sum = sum(sum(spec_t_seg));
    spec_t_seg = spec_t_seg/(spec_t_seg_sum+eps);
    spec_f_seg = abs(spec_f(:,index));
    spec_f_seg_sum = sum(sum(spec_f_seg));
    spec_f_seg = spec_f_seg/(spec_f_seg_sum+eps);
    
    [w, zf, zt, h] = coupled_plca(spec_f_seg, spec_t_seg, b_freq, b_time, plca_options.dic_size, plca_options.max_iter);

    super_spec = spec_t_seg_sum*w*diag(zt)*h;
    super_spec_buffer{count} = super_spec;
end

super_spec = [super_spec_buffer{:}];


%%
 



